/*
 * Copyright (C) 2012 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.example.testadapters;

import android.app.LoaderManager;
import android.content.Context;
import android.content.CursorLoader;
import android.content.Loader;
import android.database.Cursor;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.provider.ContactsContract.CommonDataKinds;
import android.widget.SimpleCursorAdapter;

/**
 * Helper class to handle all the callbacks that occur when interacting with loaders.  Most of the
 * interesting code in this sample app will be in this file.
 */
public class ContactablesLoaderCallbacks implements LoaderManager.LoaderCallbacks<Cursor> {

    Context mContext;
    SimpleCursorAdapter mAdapter;

    public static final String TAG = "ContactablesLoaderCallbacks";

    public ContactablesLoaderCallbacks(Context context, SimpleCursorAdapter adapter) {
        mContext = context;
        mAdapter = adapter;
    }

    @Override
    public Loader<Cursor> onCreateLoader(int loaderIndex, Bundle args) {
     // These are the Contacts rows that we will retrieve
        String[] projection = new String[] {ContactsContract.Contacts._ID,
            ContactsContract.Contacts.DISPLAY_NAME};

        // This is the select criteria
        String selection = "((" + 
            ContactsContract.Contacts.DISPLAY_NAME + " NOTNULL) AND (" +
            ContactsContract.Contacts.DISPLAY_NAME + " != '' ))";

        // Sort results such that rows for the same contact stay together.
        String sortBy = CommonDataKinds.Contactables.LOOKUP_KEY;
//        String sortBy = null;

        return new CursorLoader(
        		mContext,	// Context
        		ContactsContract.Contacts.CONTENT_URI, // URI representing the table/resource to be queried
                projection, // projection - the list of columns to return.  Null means "all"
                selection,  // selection - Which rows to return (condition rows must match)
                null, 		// selection args - can be provided separately and subbed into selection.
                sortBy);	// string specifying sort order
        
    }

    // Called when a previously created loader has finished loading
    public void onLoadFinished(Loader<Cursor> loader, Cursor data) {
    	// Swap the new cursor in.  (The framework will take care of closing the
    	// old cursor once we return.)
    	mAdapter.changeCursor(data);
    }

    // Called when a previously created loader is reset, making the data unavailable
    public void onLoaderReset(Loader<Cursor> loader) {
    	// This is called when the last Cursor provided to onLoadFinished()
    	// above is about to be closed.  We need to make sure we are no
    	// longer using it.
    	mAdapter.changeCursor(null);
    }
}
