package com.example.testadapters;

import android.app.Activity;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.widget.ArrayAdapter;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.Toast;

public class MainActivity extends Activity {

    public static final int CONTACT_QUERY_LOADER = 0;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		ListAdapter adapter = null;
 		int example = 3;
		
		switch(example){
		
		case 1:
			// 1) Define the array manually
			// Example 1
			//		String[] myStringArray = {"Fante", "Cavallo", "Re"};
			// Example 2
			String[] myStringArray = {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"};

			// create its adapter
			adapter = new ArrayAdapter<CharSequence>(this, 
					android.R.layout.simple_list_item_1, myStringArray);
			break;

		
		case 2:
			// 2) Use an array resource (hardcoded in the project, but not within the code).
			//    See docs at http://developer.android.com/guide/topics/resources/available-resources.html
			//    and http://developer.android.com/guide/topics/resources/string-resource.html
			//    and look for "arrays"
			adapter = ArrayAdapter.createFromResource(this, R.array.months,
					android.R.layout.simple_list_item_1);
			break;

		
		case 3: 
			// 3) Use a cursor adapter to access your personal Contact List

			// For the cursor adapter, specify which columns go into which views
			String[] fromColumns1 = {ContactsContract.Contacts.DISPLAY_NAME, ContactsContract.Contacts._ID};
			int[] toViews1 = {android.R.id.text1, android.R.id.text2}; // The TextView in simple_list_item_1
			
			// Create an empty adapter we will use to display the loaded data.
			// We pass null for the cursor, then update it
			adapter = new SimpleCursorAdapter(
					this, 			// context
					android.R.layout.simple_list_item_2,	// layout
					getContacts(),	// cursor 
					fromColumns1, 	// the cursor columns that are input to this adapter
					toViews1, 		// the views used to display the columns in "from"
					0);

			break;
			
		case 4: 
			// 4) Use a cursor adapter to access your personal Contact List
			//    Do this by explicitly declaring a Loader/LoaderManager

			// For the cursor adapter, specify which columns go into which views
			String[] fromColumns = {ContactsContract.Contacts.DISPLAY_NAME, ContactsContract.Contacts._ID};
			int[] toViews = {android.R.id.text1, android.R.id.text2}; // The TextView in simple_list_item_1
			
			// Create an empty adapter we will use to display the loaded data.
			// We pass null for the cursor, then update it
			adapter = new SimpleCursorAdapter(
					this, 			// context
					android.R.layout.simple_list_item_2,	// layout
					null,			// cursor (we are not providing it now)
					fromColumns, 	// the cursor columns that are input to this adapter
					toViews, 		// the views used to display the columns in "from"
					0);
		
            ContactablesLoaderCallbacks loaderCallbacks = new ContactablesLoaderCallbacks(this, (SimpleCursorAdapter)adapter);

            // Start the loader with the new query, and an object that will handle all callbacks.
            getLoaderManager().restartLoader(CONTACT_QUERY_LOADER, null, loaderCallbacks);
            break;

		case 5:
			// 5) get a random row from the data source and get a given column as a string
			Cursor cursor = getContacts();
			int random = (int )(Math.random() * cursor.getCount() + 1);
			cursor.moveToPosition(random);
            Toast.makeText(this, "Random Contact: " + cursor.getString(1), Toast.LENGTH_LONG).show();
		}
		
		ListView lv = (ListView) findViewById(R.id.listView1);
		lv.setAdapter(adapter);
	}

	 Cursor getContacts() {
		    // Run query
		    Uri uri = ContactsContract.Contacts.CONTENT_URI;
		    String[] projection = new String[] { ContactsContract.Contacts._ID,
		        ContactsContract.Contacts.DISPLAY_NAME };
		    String selection = ContactsContract.Contacts.IN_VISIBLE_GROUP + " = '"
		        + ("1") + "'";
		    String[] selectionArgs = null;
		    // note that we sort differently here
		    String sortOrder = ContactsContract.Contacts.DISPLAY_NAME
		        + " COLLATE LOCALIZED ASC";

		    return getContentResolver().query(uri, projection, selection, selectionArgs, sortOrder);
		    
		  }

}
